@@ -6,8 +6,9 @@
 
 import sys
 import time
+from pyprind.prog_class import Prog
 
-class ProgPercent():
+class ProgPercent(Prog):
     """Initializes a percentage indicator object that allows visuzalization
        of an iterational computation in the standard output screen. 
 
@@ -16,12 +17,10 @@ class ProgPercent():
         track_time (bool): prints elapsed time
 
     """
-    def __init__(self, iterations, track_time=True):
-        self.cnt = 1
-        self.max_iter = float(iterations) # accommodation for Python 2.x users
+    def __init__(self, iterations, track_time=True, stream=2):
+        Prog.__init__(self, iterations, track_time, stream)
         self.perc = 0
-        self.time = [time.clock(), 0]
-        self.track = track_time
+        self.max_iter = float(self.max_iter) # accommodation for Python 2.x users
         self.__print_update()
 
     def __calc_percent(self):
@@ -30,19 +29,20 @@ class ProgPercent():
 
     def __print_update(self):
         """Prints formatted integer percentage and tracked time to the screen."""
-        sys.stdout.write('\r[%3d %%]' % (self.perc))
+        self._stream_out('\r[%3d %%]' % (self.perc))
         if self.track:
             self.time[1] = time.clock()
-            sys.stdout.write('   elapsed: %.3f sec' % self.time[1])
+            self._stream_out('   elapsed: %.3f sec' % self.time[1])
+            self._stream_flush()
 
     def update(self):
         """Updates the percentage indicator in every iteration of the task."""
+        self.cnt += 1
         next_perc = self.__calc_percent()
         if next_perc > self.perc:
             self.perc = next_perc
             self.__print_update()
-            sys.stdout.flush()
-        self.cnt += 1
+            self._stream_flush()
         if self.cnt == self.max_iter:
-            sys.stdout.write('\n') 
+            self._stream_out('\n') 
  
